==> php55-owncloud-8.2.2.tgz: share/owncloud/lib/l10n/az.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"configurasiya\" direktoriyasının daxilində yazmaq mümkün deyil",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Adətən tez həll etmək üçün WEB serverdə yazma yetkisi verilir",
    "See %s" : "Bax %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Bu adətən %s config qovluğuna web server üçün yazma yetkisi verdikdə, %s tərəfindən fix edilə bilir. ",
    "Sample configuration detected" : "Konfiqurasiya nüsxəsi təyin edildi",
    "Help" : "Kömək",
    "Personal" : "Şəxsi",
    "Users" : "İstifadəçilər",
    "Admin" : "İnzibatçı",
    "Recommended" : "Məsləhətlidir",
    "No app name specified" : "Proqram adı təyin edilməyib",
    "Unknown filetype" : "Fayl tipi bəlli deyil.",
    "Invalid image" : "Yalnış şəkil",
    "today" : "Bu gün",
    "seconds ago" : "saniyələr öncə",
    "App directory already exists" : "Proqram təminatı qovluğu artıq mövcuddur.",
    "Can't create app folder. Please fix permissions. %s" : "Proqram təminatı qovluğunu yaratmaq mümkün olmadı. Xahiş edilir yetkiləri düzgün təyin edəsiniz. %s",
    "Application is not enabled" : "Proqram təminatı aktiv edilməyib",
    "Authentication error" : "Təyinat metodikası",
    "Token expired. Please reload page." : "Token vaxtı bitib. Xahiş olunur səhifəni yenidən yükləyəsiniz.",
    "Unknown user" : "Istifadəçi tanınmır ",
    "%s enter the database username." : "Verilənlər bazası istifadəçi adını %s daxil et.",
    "%s enter the database name." : "Verilənlər bazası adını %s daxil et.",
    "Oracle connection could not be established" : "Oracle qoşulması alınmır",
    "Oracle username and/or password not valid" : "Oracle istifadəçi adı və/ya şifrəsi düzgün deyil",
    "DB Error: \"%s\"" : "DB səhvi: \"%s\"",
    "Set an admin username." : "İnzibatçı istifadəçi adını təyin et.",
    "Set an admin password." : "İnzibatçı şifrəsini təyin et.",
    "%s shared »%s« with you" : "%s yayımlandı »%s« sizinlə",
    "Sharing %s failed, because the file does not exist" : "%s yayımlanmasında səhv baş verdi ona görə ki, fayl mövcud deyil.",
    "You are not allowed to share %s" : "%s-in yayimlanmasına sizə izin verilmir",
    "Share type %s is not valid for %s" : "Yayımlanma  tipi %s etibarlı deyil %s üçün",
    "A valid username must be provided" : "Düzgün istifadəçi adı daxil edilməlidir",
    "A valid password must be provided" : "Düzgün şifrə daxil edilməlidir",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu ola bilər ki, cache/accelerator such tərəfindən cağırılıb hansi ki, Zend OPcache və eAccelerator-da olduğu kimidir."
},
"nplurals=2; plural=(n != 1);");

==> php55-owncloud-9.0.0.tgz: share/owncloud/lib/l10n/az.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"configurasiya\" direktoriyasının daxilində yazmaq mümkün deyil",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Adətən tez həll etmək üçün WEB serverdə yazma yetkisi verilir",
    "See %s" : "Bax %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Bu adətən %s config qovluğuna web server üçün yazma yetkisi verdikdə, %s tərəfindən fix edilə bilir. ",
    "Sample configuration detected" : "Konfiqurasiya nüsxəsi təyin edildi",
    "Help" : "Kömək",
    "Personal" : "Şəxsi",
    "Users" : "İstifadəçilər",
    "Admin" : "İnzibatçı",
    "Recommended" : "Məsləhətlidir",
    "No app name specified" : "Proqram adı təyin edilməyib",
    "Unknown filetype" : "Fayl tipi bəlli deyil.",
    "Invalid image" : "Yalnış şəkil",
    "today" : "Bu gün",
    "seconds ago" : "saniyələr öncə",
    "App directory already exists" : "Proqram təminatı qovluğu artıq mövcuddur.",
    "Can't create app folder. Please fix permissions. %s" : "Proqram təminatı qovluğunu yaratmaq mümkün olmadı. Xahiş edilir yetkiləri düzgün təyin edəsiniz. %s",
    "Application is not enabled" : "Proqram təminatı aktiv edilməyib",
    "Authentication error" : "Təyinat metodikası",
    "Token expired. Please reload page." : "Token vaxtı bitib. Xahiş olunur səhifəni yenidən yükləyəsiniz.",
    "Unknown user" : "Istifadəçi tanınmır ",
    "%s enter the database username." : "Verilənlər bazası istifadəçi adını %s daxil et.",
    "%s enter the database name." : "Verilənlər bazası adını %s daxil et.",
    "Oracle connection could not be established" : "Oracle qoşulması alınmır",
    "Oracle username and/or password not valid" : "Oracle istifadəçi adı və/ya şifrəsi düzgün deyil",
    "DB Error: \"%s\"" : "DB səhvi: \"%s\"",
    "Set an admin username." : "İnzibatçı istifadəçi adını təyin et.",
    "Set an admin password." : "İnzibatçı şifrəsini təyin et.",
    "%s shared »%s« with you" : "%s yayımlandı »%s« sizinlə",
    "Sharing %s failed, because the file does not exist" : "%s yayımlanmasında səhv baş verdi ona görə ki, fayl mövcud deyil.",
    "You are not allowed to share %s" : "%s-in yayimlanmasına sizə izin verilmir",
    "Share type %s is not valid for %s" : "Yayımlanma  tipi %s etibarlı deyil %s üçün",
    "A valid username must be provided" : "Düzgün istifadəçi adı daxil edilməlidir",
    "A valid password must be provided" : "Düzgün şifrə daxil edilməlidir",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu ola bilər ki, cache/accelerator such tərəfindən cağırılıb hansi ki, Zend OPcache və eAccelerator-da olduğu kimidir.",
    "Storage not available" : "İnformasiya daşıyıcısı mövcud deyil"
},
"nplurals=2; plural=(n != 1);");
